@@ -14,22 +14,18 @@
 #   limitations under the License.
 
 __author__ = 'Michael Gruber'
-__version__ = '0.2.9'
+__version__ = '0.2.10'
 
 __all__ = ['ANY_BOOLEAN',
            'ANY_DICTIONARY',
-           'ANY_FILE',
            'ANY_FLOAT',
            'ANY_INTEGER',
            'ANY_LIST',
-           'ANY_LONG',
            'ANY_SLICE',
            'ANY_STRING',
            'ANY_TUPLE',
-           'ANY_UNICODE',
            'ANY_VALUE',
            'ANY_VALUES',
-           'ANY_XRANGE',
            'AT_LEAST_ONCE',
            'NEVER',
            'UnitTests',
@@ -68,18 +64,14 @@ LOGGER = getLogger(__name__)
 
 ANY_BOOLEAN = AnyValueOfTypeMatcher(bool)
 ANY_DICTIONARY = AnyValueOfTypeMatcher(dict)
-ANY_FILE = AnyValueOfTypeMatcher(file)
 ANY_FLOAT = AnyValueOfTypeMatcher(float)
 ANY_INTEGER = AnyValueOfTypeMatcher(int)
 ANY_LIST = AnyValueOfTypeMatcher(list)
-ANY_LONG = AnyValueOfTypeMatcher(long)
 ANY_SLICE = AnyValueOfTypeMatcher(slice)
 ANY_STRING = AnyValueOfTypeMatcher(str)
 ANY_TUPLE = AnyValueOfTypeMatcher(tuple)
-ANY_UNICODE = AnyValueOfTypeMatcher(unicode)
 ANY_VALUE = AnyValueMatcher()
 ANY_VALUES = AnyValuesMatcher()
-ANY_XRANGE = AnyValueOfTypeMatcher(xrange)
 
 AT_LEAST_ONCE = AtLeastOnceMatcher()
 NEVER = NeverMatcher()
